@@ -13,6 +13,7 @@
 import datetime
 import debtcollector
 import functools
+import io
 import itertools
 import logging
 import logging.config
@@ -23,25 +24,11 @@ import sys
 import traceback
 
 from dateutil import tz
-import six
-from six import moves
 
 from oslo_context import context as context_utils
 from oslo_serialization import jsonutils
 from oslo_utils import encodeutils
 
-if six.PY3:
-    from functools import reduce
-
-
-try:
-    # Test if to_primitive() has the fallback parameter added
-    # in oslo.serialization 2.21.1
-    jsonutils.to_primitive(1, fallback=repr)
-    _HAVE_JSONUTILS_FALLBACK = True
-except TypeError:
-    _HAVE_JSONUTILS_FALLBACK = False
-
 
 def _dictify_context(context):
     if getattr(context, 'get_logging_values', None):
@@ -94,10 +81,10 @@ def _update_record_with_context(record):
 def _ensure_unicode(msg):
     """Do our best to turn the input argument into a unicode object.
     """
-    if isinstance(msg, six.text_type):
+    if isinstance(msg, str):
         return msg
-    if not isinstance(msg, six.binary_type):
-        return six.text_type(msg)
+    if not isinstance(msg, bytes):
+        return str(msg)
     return encodeutils.safe_decode(
         msg,
         incoming='utf-8',
@@ -166,7 +153,7 @@ def _get_error_summary(record):
                 error_summary = error_summary.split('\n', 1)[0]
         except TypeError as type_err:
             # Work around https://bugs.python.org/issue28603
-            error_summary = "<exception with %s>" % six.text_type(type_err)
+            error_summary = "<exception with %s>" % str(type_err)
         finally:
             # Remove the local reference to the exception and
             # traceback to avoid a memory leak through the frame
@@ -185,16 +172,13 @@ _MSG_KEY_REGEX = re.compile(r'(%+)\((\w+)\)')
 
 
 def _json_dumps_with_fallback(obj):
-    if _HAVE_JSONUTILS_FALLBACK:
-        # Bug #1593641: If an object cannot be serialized to JSON, convert
-        # it using repr() to prevent serialization errors. Using repr() is
-        # not ideal, but serialization errors are unexpected on logs,
-        # especially when the code using logs is not aware that the
-        # JSONFormatter will be used.
-        convert = functools.partial(jsonutils.to_primitive, fallback=repr)
-        return jsonutils.dumps(obj, default=convert)
-    else:
-        return jsonutils.dumps(obj)
+    # Bug #1593641: If an object cannot be serialized to JSON, convert
+    # it using repr() to prevent serialization errors. Using repr() is
+    # not ideal, but serialization errors are unexpected on logs,
+    # especially when the code using logs is not aware that the
+    # JSONFormatter will be used.
+    convert = functools.partial(jsonutils.to_primitive, fallback=repr)
+    return jsonutils.dumps(obj, default=convert)
 
 
 class JSONFormatter(logging.Formatter):
@@ -213,10 +197,10 @@ class JSONFormatter(logging.Formatter):
             lines = traceback.format_exception(*ei)
         except TypeError as type_error:
             # Work around https://bugs.python.org/issue28603
-            msg = six.text_type(type_error)
+            msg = str(type_error)
             lines = ['<Unprintable exception due to %s>\n' % msg]
         if strip_newlines:
-            lines = [moves.filter(
+            lines = [filter(
                 lambda x: x,
                 line.rstrip().splitlines()) for line in lines]
             lines = list(itertools.chain(*lines))
@@ -306,17 +290,25 @@ class FluentFormatter(logging.Formatter):
         except socket.error:
             self.hostname = None
         self.cmdline = " ".join(sys.argv)
+        try:
+            # check if running under uwsgi
+            import uwsgi
+            svc_name = uwsgi.opt.get("name")
+            self.uwsgi_name = svc_name
+        except Exception:
+            self.uwsgi_name = None
 
     def formatException(self, exc_info, strip_newlines=True):
         try:
             lines = traceback.format_exception(*exc_info)
         except TypeError as type_error:
             # Work around https://bugs.python.org/issue28603
-            msg = six.text_type(type_error)
+            msg = str(type_error)
             lines = ['<Unprintable exception due to %s>\n' % msg]
         if strip_newlines:
-            lines = reduce(lambda a, line: a + line.rstrip().splitlines(),
-                           lines, [])
+            lines = functools.reduce(lambda a,
+                                     line: a + line.rstrip().splitlines(),
+                                     lines, [])
         return lines
 
     def format(self, record):
@@ -357,8 +349,7 @@ class FluentFormatter(logging.Formatter):
             message['context'] = {}
         extra.pop('context', None)
         # NOTE(vdrok): try to dump complex objects
-        primitive_types = six.string_types + six.integer_types + (
-            bool, type(None), float, list, dict)
+        primitive_types = (str, int, bool, type(None), float, list, dict)
         for key, value in extra.items():
             if not isinstance(value, primitive_types):
                 extra[key] = _json_dumps_with_fallback(value)
@@ -367,6 +358,9 @@ class FluentFormatter(logging.Formatter):
         if record.exc_info:
             message['traceback'] = self.formatException(record.exc_info)
 
+        if self.uwsgi_name:
+            message["uwsgi_name"] = self.uwsgi_name
+
         return message
 
 
@@ -411,20 +405,6 @@ class ContextFormatter(logging.Formatter):
 
     def format(self, record):
         """Uses contextstring if request_id is set, otherwise default."""
-        if six.PY2:
-            should_use_unicode = True
-            args = (record.args.values() if isinstance(record.args, dict)
-                    else record.args)
-            for arg in args or []:
-                try:
-                    six.text_type(arg)
-                except UnicodeDecodeError:
-                    should_use_unicode = False
-                    break
-            if (not isinstance(record.msg, six.text_type)
-                    and should_use_unicode):
-                record.msg = _ensure_unicode(record.msg)
-
         # store project info
         record.project = self.project
         record.version = self.version
@@ -513,11 +493,8 @@ class ContextFormatter(logging.Formatter):
 
         self._compute_iso_time(record)
 
-        if sys.version_info < (3, 2):
-            self._fmt = fmt
-        else:
-            self._style = logging.PercentStyle(fmt)
-            self._fmt = self._style._fmt
+        self._style = logging.PercentStyle(fmt)
+        self._fmt = self._style._fmt
 
         try:
             return logging.Formatter.format(self, record)
@@ -535,16 +512,16 @@ class ContextFormatter(logging.Formatter):
                 return logging.Formatter.formatException(self, exc_info)
             except TypeError as type_error:
                 # Work around https://bugs.python.org/issue28603
-                msg = six.text_type(type_error)
+                msg = str(type_error)
                 return '<Unprintable exception due to %s>\n' % msg
 
-        stringbuffer = moves.StringIO()
+        stringbuffer = io.StringIO()
         try:
             traceback.print_exception(exc_info[0], exc_info[1], exc_info[2],
                                       None, stringbuffer)
         except TypeError as type_error:
             # Work around https://bugs.python.org/issue28603
-            msg = six.text_type(type_error)
+            msg = str(type_error)
             stringbuffer.write('<Unprintable exception due to %s>\n' % msg)
 
         lines = stringbuffer.getvalue().split('\n')
